summaryrefslogtreecommitdiffstats
path: root/kexi/kexidb/dbproperties.h
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/kexidb/dbproperties.h')
-rw-r--r--kexi/kexidb/dbproperties.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/kexi/kexidb/dbproperties.h b/kexi/kexidb/dbproperties.h
index 91aed7e27..d4b193fa0 100644
--- a/kexi/kexidb/dbproperties.h
+++ b/kexi/kexidb/dbproperties.h
@@ -38,28 +38,28 @@ class KEXI_DB_EXPORT DatabaseProperties : public KexiDB::Object
If there's no such property defined, it will be added. Existing value will be overwritten.
Note that to execute this method, database must be opened in read-write mode.
\return true on successful data. Connection */
- bool setValue( const QString& name, const QVariant& value );
+ bool setValue( const TQString& name, const TQVariant& value );
/*! Sets \a caption for for property \a name.
Usually it shouldn't be translated: trnaslation can be performed before displaying. */
- bool setCaption( const QString& name, const QString& caption );
+ bool setCaption( const TQString& name, const TQString& caption );
//! \return property value for \a propeName available for this driver.
- //! If there's no such property defined for driver, Null QVariant value is returned.
- QVariant value( const QString& name );
+ //! If there's no such property defined for driver, Null TQVariant value is returned.
+ TQVariant value( const TQString& name );
//! \return translated property caption for \a name.
//! If there's no such property defined for driver, empty string value is returned.
- QString caption( const QString& name );
+ TQString caption( const TQString& name );
//! \return a list of available property names.
- QStringList names();
+ TQStringList names();
protected:
DatabaseProperties(Connection *conn);
~DatabaseProperties();
- QGuardedPtr<Connection> m_conn;
+ TQGuardedPtr<Connection> m_conn;
friend class Connection;
};
}